pub struct CPlayerPosition {
pub teleport_id: i32,
pub pos: DVec3,
pub vel: DVec3,
pub yaw: f32,
pub pitch: f32,
pub relatives: RelativeMovement,
}Expand description
Sent to teleport a player to a new position.
The client must acknowledge this packet by sending SAcceptTeleportation
with the same teleport ID. Until acknowledged, the server will reject
position updates from the client.
Fields
teleport_id: i32Unique teleport ID that must be echoed back by the client.
pos: DVec3Target position
vel: DVec3Target velocity (delta movement)
yaw: f32Target yaw (Y rotation)
pitch: f32Target pitch (X rotation)
relatives: RelativeMovementRelative movement flags
Implementations
Sourceimpl CPlayerPosition
impl CPlayerPosition
Sourcepub const fn new(
teleport_id: i32,
pos: DVec3,
vel: DVec3,
yaw: f32,
pitch: f32,
relatives: RelativeMovement,
) -> Self
pub const fn new( teleport_id: i32, pos: DVec3, vel: DVec3, yaw: f32, pitch: f32, relatives: RelativeMovement, ) -> Self
Creates a teleport packet with explicit relative flags.
Sourcepub const fn absolute(
teleport_id: i32,
pos: DVec3,
yaw: f32,
pitch: f32,
) -> Self
pub const fn absolute( teleport_id: i32, pos: DVec3, yaw: f32, pitch: f32, ) -> Self
Creates a new absolute teleport packet.
Sourcepub const fn absolute_with_velocity(
teleport_id: i32,
pos: DVec3,
vel: DVec3,
yaw: f32,
pitch: f32,
) -> Self
pub const fn absolute_with_velocity( teleport_id: i32, pos: DVec3, vel: DVec3, yaw: f32, pitch: f32, ) -> Self
Creates a new absolute teleport packet with explicit delta movement.
Sourcepub const fn with_relative_rotation(teleport_id: i32, pos: DVec3) -> Self
pub const fn with_relative_rotation(teleport_id: i32, pos: DVec3) -> Self
Creates a teleport packet with relative rotation (keeps current rotation).