pub struct RelativeMovement(pub i32);Expand description
Relative position/rotation flags.
When a flag is set, the corresponding value is relative to the player’s current value. When not set, the value is absolute.
Tuple Fields
0: i32Implementations
Sourceimpl RelativeMovement
impl RelativeMovement
Sourcepub const ROTATE_DELTA: i32
pub const ROTATE_DELTA: i32
Rotate delta is relative
Sourcepub const NONE: RelativeMovement
pub const NONE: RelativeMovement
No relative flags (all values are absolute)
Sourcepub const ROTATION: RelativeMovement
pub const ROTATION: RelativeMovement
All rotation flags.
Sourcepub const DELTA: RelativeMovement
pub const DELTA: RelativeMovement
Vanilla delta movement flags, including rotated-delta semantics.
Sourcepub const fn is_x_relative(self) -> bool
pub const fn is_x_relative(self) -> bool
Returns true if the X position is relative.
Sourcepub const fn is_y_relative(self) -> bool
pub const fn is_y_relative(self) -> bool
Returns true if the Y position is relative.
Sourcepub const fn is_z_relative(self) -> bool
pub const fn is_z_relative(self) -> bool
Returns true if the Z position is relative.
Sourcepub const fn is_y_rot_relative(self) -> bool
pub const fn is_y_rot_relative(self) -> bool
Returns true if yaw is relative.
Sourcepub const fn is_x_rot_relative(self) -> bool
pub const fn is_x_rot_relative(self) -> bool
Returns true if pitch is relative.
Sourcepub const fn is_delta_x_relative(self) -> bool
pub const fn is_delta_x_relative(self) -> bool
Returns true if delta X is relative.
Sourcepub const fn is_delta_y_relative(self) -> bool
pub const fn is_delta_y_relative(self) -> bool
Returns true if delta Y is relative.
Sourcepub const fn is_delta_z_relative(self) -> bool
pub const fn is_delta_z_relative(self) -> bool
Returns true if delta Z is relative.
Sourcepub const fn rotates_delta(self) -> bool
pub const fn rotates_delta(self) -> bool
Returns true if current delta movement is rotated by the teleport rotation delta.